==> mingw-w64-freecad-0.21.2-7.src.tar.zst: FreeCAD-0.21.2/src/Mod/Inspection/Gui/Resources/translations/Inspection_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdInspectElement</name>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Inspection</source>
      <translation>檢查</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <source>Inspection...</source>
      <translation type="unfinished">Inspection...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Get distance information</source>
      <translation type="unfinished">Get distance information</translation>
    </message>
  </context>
  <context>
    <name>CmdVisualInspection</name>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Inspection</source>
      <translation>檢查</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="49"/>
      <source>Visual inspection...</source>
      <translation type="unfinished">Visual inspection...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <location filename="../../Command.cpp" line="51"/>
      <source>Visual inspection</source>
      <translation type="unfinished">Visual inspection</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../VisualInspection.cpp" line="230"/>
      <source>Visual Inspection</source>
      <translation type="unfinished">Visual Inspection</translation>
    </message>
  </context>
  <context>
    <name>InspectionGui::VisualInspection</name>
    <message>
      <location filename="../../VisualInspection.ui" line="14"/>
      <source>Visual Inspection</source>
      <translation type="unfinished">Visual Inspection</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="23"/>
      <source>Actual</source>
      <translation type="unfinished">Actual</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="39"/>
      <location filename="../../VisualInspection.ui" line="66"/>
      <source>Objects</source>
      <translation>物件</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="50"/>
      <source>Nominal</source>
      <translation type="unfinished">Nominal</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="77"/>
      <source>Parameter</source>
      <translation>參數</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="97"/>
      <source>Search distance</source>
      <translation type="unfinished">Search distance</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="129"/>
      <location filename="../../VisualInspection.ui" line="174"/>
      <source> mm</source>
      <translation> mm</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="145"/>
      <source>Thickness</source>
      <translation>厚度</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="455"/>
      <source>Remove annotations</source>
      <translation>刪除註解</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="456"/>
      <source>Do you want to remove all annotations?</source>
      <translation type="unfinished">Do you want to remove all annotations?</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="508"/>
      <source>Annotation</source>
      <translation>注釋</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="511"/>
      <source>Leave info mode</source>
      <translation>離開訊息模式</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="632"/>
      <source>Distance: &gt; %1</source>
      <translation type="unfinished">Distance: &gt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="635"/>
      <source>Distance: &lt; %1</source>
      <translation type="unfinished">Distance: &lt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="654"/>
      <location filename="../../ViewProviderInspection.cpp" line="670"/>
      <source>Distance: %1</source>
      <translation type="unfinished">Distance: %1</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0rc2-3.src.tar.zst: FreeCAD-1.0rc2/src/Mod/Inspection/Gui/Resources/translations/Inspection_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdInspectElement</name>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Inspection</source>
      <translation>檢查</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <source>Inspection...</source>
      <translation>檢查...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Get distance information</source>
      <translation>取得距離資訊</translation>
    </message>
  </context>
  <context>
    <name>CmdVisualInspection</name>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Inspection</source>
      <translation>檢查</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="49"/>
      <source>Visual inspection...</source>
      <translation>視覺檢查...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <location filename="../../Command.cpp" line="51"/>
      <source>Visual inspection</source>
      <translation>視覺檢查</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../VisualInspection.cpp" line="237"/>
      <source>Visual Inspection</source>
      <translation>視覺檢查</translation>
    </message>
  </context>
  <context>
    <name>InspectionGui::VisualInspection</name>
    <message>
      <location filename="../../VisualInspection.ui" line="14"/>
      <source>Visual Inspection</source>
      <translation>視覺檢查</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="23"/>
      <source>Actual</source>
      <translation>Actual</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="39"/>
      <location filename="../../VisualInspection.ui" line="66"/>
      <source>Objects</source>
      <translation>物件</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="50"/>
      <source>Nominal</source>
      <translation>Nominal</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="77"/>
      <source>Parameter</source>
      <translation>參數</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="97"/>
      <source>Search distance</source>
      <translation>搜尋距離</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="129"/>
      <location filename="../../VisualInspection.ui" line="174"/>
      <source> mm</source>
      <translation> mm</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="145"/>
      <source>Thickness</source>
      <translation>厚度</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="489"/>
      <source>Remove annotations</source>
      <translation>刪除註解</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="490"/>
      <source>Do you want to remove all annotations?</source>
      <translation>您想刪除所有注釋嗎?</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="548"/>
      <source>Annotation</source>
      <translation>注釋</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="551"/>
      <source>Leave info mode</source>
      <translation>離開訊息模式</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="682"/>
      <source>Distance: &gt; %1</source>
      <translation>距離: &gt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="686"/>
      <source>Distance: &lt; %1</source>
      <translation>距離: &lt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="706"/>
      <location filename="../../ViewProviderInspection.cpp" line="723"/>
      <source>Distance: %1</source>
      <translation>距離: %1</translation>
    </message>
  </context>
</TS>
